/*
	*
	* This file is a part of DesQ.
	* DesQSession is a Session manager for DesQ Shell
    * Copyright 2020 Marcus Britanicus
	*

	*
	* This file is derived from QSingleApplication, originally written
	* as a part of Qt Solutions. For license read DesQApplication.cpp
	*

	*
	* This program is free software; you can redistribute it and/or modify
	* it under the terms of the GNU General Public License as published by
	* the Free Software Foundation; either version 3 of the License, or
	* at your option, any later version.
	*

	*
	* This program is distributed in the hope that it will be useful,
	* but WITHOUT ANY WARRANTY; without even the implied warranty of
	* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	* GNU General Public License for more details.
	*

	*
	* You should have received a copy of the GNU General Public License
	* along with this program; if not, write to the Free Software
	* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
	* MA 02110-1301, USA.
	*
*/

#pragma once

#include "DesQGlobals.hpp"
#include <QCoreApplication>

#if defined(qApp)
#undef qApp
#endif

#define qApp (static_cast<DesQCoreApplication *>(QCoreApplication::instance()))

class DesQIpcServer;

class DesQCoreApplication : public QCoreApplication {
    Q_OBJECT;

	public:
		DesQCoreApplication( const QString &id, int &argc, char **argv );
		~DesQCoreApplication();

		bool isRunning();
		QString id() const;

        DesQIpcServer *ipcServer();

	public Q_SLOTS:
		bool sendMessage( const QString &message );
		void disconnect();

	Q_SIGNALS:
		void messageReceived( const QString &message );

	private:
        QLockFile *lockFile = nullptr;
		DesQIpcServer *mIpcServer = nullptr;
        QString mSocketName;
        QString mAppId;
};
